## 2.1.0 - 2026-02-22

### ✨ Added

- [#1676](https://github.com/edgarrmondragon/citric/issues/1676) New `Question`, `QuestionL10n`, and `AnswerOption` classes for composing LimeSurvey questions as Python objects and importing them via `client.import_question(q.to_lsq(), ...)`

### 🛠️ Refactored

- [#1633](https://github.com/edgarrmondragon/citric/issues/1633) Use `Path.write_bytes` where possible

### 📚 Documentation

- [#1666](https://github.com/edgarrmondragon/citric/issues/1666) Expose `/llms.txt` file

- [#1667](https://github.com/edgarrmondragon/citric/issues/1667) Put contributing documents in a dropdown to declutter the sidenav

### 📦 Packaging

- [#1503](https://github.com/edgarrmondragon/citric/issues/1503) Dropped support for Python 3.9
